@@ -357,8 +357,7 @@ class mustafa:
             #print(m.modelsorder[v])
         print(highalgo,m.latesttraining[highalgo],' is mustafa')
         return {str(highalgo):m.latesttraining[highalgo]}
-    def s(m):
-        successful(m)
+
     def successful(m):
         a = []
         for k in m.trainings:
@@ -458,4 +457,4 @@ class mustafa:
 #             except Exception as e:
 #                 print(str(e)+" (algorithm skipped)")
             m.latesttraining = gridsearches
-        return gridsearches
\ No newline at end of file
+        return gridsearches
